@@ -104,9 +104,9 @@ class MongoAlchemy(object):
 
         uri = _get_mongo_uri(app)
         self.session = session.Session.connect(app.config.get('MONGOALCHEMY_DATABASE'),
+                                               safe=app.config.get('MONGOALCHEMY_SAFE_SESSION', False),
                                                host=uri,
                                                )
-        self.session.safe = app.config.get('MONGOALCHEMY_SAFE_SESSION', False)
         self.Document._session = self.session
 
 class Pagination(object):
@@ -245,9 +245,13 @@ class Document(document.Document):
     #: for instances of this document.
     query = None
 
-    def save(self):
-        """Saves the document itself in the database."""
-        self._session.insert(self)
+    def save(self, safe=None):
+        """Saves the document itself in the database.
+
+        The optional ``safe`` argument is a boolean that specifies if the
+        remove method should wait for the operation to complete.
+        """
+        self._session.insert(self, safe=safe)
         self._session.flush()
 
     def remove(self, safe=None):
